@@ -1,9 +1,9 @@
 package Net::DNS::SEC::ECDSA;
 
 #
-# $Id: ECDSA.pm 1677 2018-05-22 11:59:10Z willem $
+# $Id: ECDSA.pm 1723 2018-12-03 09:17:48Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1677 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1723 $)[1];
 
 
 =head1 NAME
@@ -46,6 +46,10 @@ use integer;
 use warnings;
 use MIME::Base64;
 
+use constant ECDSA_configured => Net::DNS::SEC::libcrypto->can('EVP_PKEY_assign_EC_KEY');
+
+BEGIN { die 'No "use Net::DNS::SEC" or no ECDSA' unless ECDSA_configured }
+
 
 my %parameters = (
 	13 => [415, 32, sub { Net::DNS::SEC::libcrypto::EVP_sha256() }],
